<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 
namespace core;

if(!defined('RS-MINI')) die();

/*
 * abstractcontroller v 1.0
 * 
 * абстрактный класс для контроллеров
 *
 */

abstract class abstractcontroller
{
    /*
     * объект дома
     *
     * @var    - object
     * @access - protected
     */
    
    protected $dom;

    /*
     * массив хранящий значения динамичных страниц
     *
     * @var    - array
     * @access - private
     */
    
    private static $dynamicValue;

    /*
     * массив хранящий параметры контроллера
     *
     * @var    - array
     * @access - private
     */
    
    private $paramList;
    
    /*
     * контсруктор
     * обратите внимания, что объект класса dom по умолчанию
     * передаются по ссылке что гарантирует нам использование одного и
     * того же экземпляра класса (по всему проекту будет существовать одна
     * копия объекта)
     * 
     * @access - public
     *
     * @param object dom       - объект класса dom
     * @param array  paramList - массив с параметрами контроллера
     */
    
    public function __construct($dom, $paramList = array())
    {
        $this->dom        = $dom;
        $this->paramList  = $paramList;
    }

    /*
     * метод возвращает заголовок страницы
     * 
     * @access - public
     *
     * @param string caption - системный заголовок
     */

    public function getCaption($caption)
    {
        return $caption;
    }

    /*
     * метод позволит проверить некоторые данные на валидацию.
     * запускается для каждого контроллера (за исключением отключенных)
     * 
     * @access - public
     * @return - true или false (404 ошибка)
     * 
     */

    public function validate()
    {
        return TRUE;
    }
   
    /*
     * запуск контроллера. основной метод контроллера.
     * если не создать подобный метод (полиморфизм) в дочернем классе
     * контроллер выдаст 404-ую ошибку
     * 
     * @access - public
     * @return - true или false (404 ошибка)
     * 
     */

    public function run()
    {
        return FALSE;
    }
    
    /*
     * метод запоминает значение динамичной страницы.
     * отрабатывает при сборке контроллеров в приложении
     * системы. необходим, что бы псевдоним динамической страницы
     * можно было получить из любого подключенного контроллера
     * 
     * @access - public
     * @return - значение дин страницы
     *
     * @param string name - имя параметра
     */

    public function setDynamicValue($name, $value)
    {
        self::$dynamicValue[$name] = $value;
    }

    /*
     * метод получает значение динамичной страницы по имени
     * 
     * @access - protected
     * @return - значение дин страницы
     *
     * @param string name - имя параметра
     */

    protected function getDynamicValue($name)
    {
        return (isset(self::$dynamicValue[$name])) ? self::$dynamicValue[$name] : NULL;
    }

    /*
     * метод получает значение параметра по имени.
     * если значение содержит запятые, то оно (значение) вернется не
     * в виде строки, а в виде массива
     * 
     * @access - protected
     * @return - значение параметра
     *
     * @param string name - имя параметра
     */

    protected function getParam($name)
    {
        if (!isset($this->paramList[$name]))
            return NULL;
            
        if (!preg_match('/[\,]+/', $this->paramList[$name]))
            return $this->paramList[$name];
        
        $params = explode(',', $this->paramList[$name]);
        
        foreach ($params as $key => $param)
            $params[$key] = trim($param);
            
        return $params;
    }
}
